--[[
Map Input/Output System
Manages map saving/loading to file
]]

iosys = {}
function iosys.init()
	function iosys.saveMap(map)
		if not map then
			print("Can't save: No map loaded.")
			return nil
		end
		local dir = love.filesystem.getUserDirectory().."/Desktop"
		local mapFile = io.open(string.format("%s/map.mtf",dir),"w")
		for y,row in ipairs(world.map) do
			for x,cell in ipairs(world.map[y]) do
				local entry = string.format("|%s,%i,%i",cell.sprite,cell.x,cell.y)
				mapFile:write(entry)
			end
			mapFile:write("\n")
		end
		mapFile:close()
		print(#map)
	end

	function iosys.loadMap()
		local stime = love.timer.getTime()
		local dir = love.filesystem.getUserDirectory().."/Desktop"
		local map = {}
		local x=0
		local y=0
		if not mapDir then mapDir={} end
		local mapFile = io.open(string.format("%s/map.mtf",dir),"r")
		for line in mapFile:lines() do
			y = y + 1
			map[y] = {}
			local lineTable = iosys.split(line,"|")
			for x,cellData in ipairs(lineTable) do
				--x = x + 1
				local cellTable = iosys.split(cellData,",")
				local cell = {
					sprite = cellTable[1];
					x = tonumber(cellTable[2]);
					y = tonumber(cellTable[3]);
				}
				map[y][x] = cell
			end
		end
		mapFile:close()
		local etime = love.timer.getTime()

		print(string.format("Map loaded: %ix%i. Contains %i cells. Took %f seconds",#map,#map,#map*#map[1],etime-stime))
		return map

	end

	function iosys.split(str, pat)  --Courtesy of http://lua-users.org/wiki/SplitJoin
	   local t = {}  -- NOTE: use {n = 0} in Lua-5.0
	   local fpat = "(.-)" .. pat
	   local last_end = 1
	   local s, e, cap = str:find(fpat, 1)
	   while s do
		  if s ~= 1 or cap ~= "" then
		 table.insert(t,cap)
		  end
		  last_end = e+1
		  s, e, cap = str:find(fpat, last_end)
	   end
	   if last_end <= #str then
		  cap = str:sub(last_end)
		  table.insert(t, cap)
	   end
	   return t
	end

	
end

------Standard callbacks
function iosys.update(dt)

end


function iosys.draw()

end


function iosys.keypress(key)
	if key == " " then
		iosys.saveMap(world.map)
	end
	
	if key == "backspace" then
		world.map = iosys.loadMap()
	end
end


function iosys.mousepress()

end