--Handle world rendering

world = {}

function world.init()
	world.tiles = {
		grass = love.graphics.newImage("source/data/grass.png");
		grassFlwr = love.graphics.newImage("source/data/grassFlwr.png");
		grassFlwr2 = love.graphics.newImage("source/data/grassFlwr2.png");
		waterMid = love.graphics.newImage("source/data/waterMid.png");
		abyss = love.graphics.newImage("source/data/abyss.png");
	}
	
	function world.mapGen(sx,sy,tSize) --Generate table of cells: sx/sy=Size in pixels tSize=Size of each tile.
		local stime = love.timer.getTime()
		local map = {}
		local xStart = ((sx*tSize)/2)*-1 -- Starting coords of top left cell.
		local yStart = ((sy*tSize)/2)*-1
		local randomSprite = ""
		for y=0,sy do
			map[y]={}
			for x=0,sx do
				if math.random(1,500) > 5 then randomSprite = "grass"
					elseif math.random()>=0.5 then randomSprite = "grassFlwr"
						else randomSprite = "grassFlwr2"
				end
				local cell = {
					sprite = randomSprite; --Sprites defined as strings to load from tile list
					x = xStart+tSize*x;
					y = yStart+tSize*y;
				}
				map[y][x]=cell
			end
		end
		local etime = love.timer.getTime()
		print(string.format("Map created in: %f seconds. Size: %ix%i: %i tiles.",etime-stime,#map,#map[1],#map*#map[1]))
		return map		
	end	
	
	function world.genRenderMap(map,ox,oy,tSize)--Returns a render map, containing tiles to render to the screen.
		if not map then
			map = {{}}
		end
		local rMap = {} 
		local buffer = 2 --How many tiles off screen should we render?
		local mapHeight = #map
		local mapWidth = #map[1]
		local renderHeight = math.ceil((love.graphics.getHeight()/tSize)+buffer)
		local renderWidth = math.ceil((love.graphics.getWidth()/tSize)+buffer)
		for y=0-buffer,renderHeight do
			for x=0-buffer,renderWidth do
				local cX=x-math.floor(ox/tSize)+(mapWidth/2) --screen cell to draw- cell offset+half map(to adjust for origin pos)
				local cY=y-math.floor(oy/tSize)+(mapHeight/2)
				if map[cY] then
					table.insert(rMap,map[cY][cX])
				end
			end
		end
		return rMap
	end

	function world.drawMap(renderMap) -- Draw all cells in the render map
		for i,cell in ipairs(renderMap) do
			love.graphics.draw(world.tiles[cell.sprite],cell.x+world.ox,cell.y+world.oy)
		end
	end

	function world.setCamera(x,y,dt) --Smoothly scoot world offsets to these coords
		local camSpeed = 3
		local tX = -x+love.graphics.getWidth()/2
		local tY = -y+love.graphics.getHeight()/2
		world.ox = math.floor(world.ox-(world.ox-tX)*dt*camSpeed)
		world.oy = math.floor(world.oy-(world.oy-tY)*dt*camSpeed)
	end
	
	
	world.ox=love.graphics.getWidth()/2
	world.oy=love.graphics.getHeight()-2000
	world.renderMap = world.genRenderMap(world.map,world.ox,world.oy,32)
	
end

------Standard callbacks
function world.update()
	world.renderMap = world.genRenderMap(world.map,world.ox,world.oy,32)

end


function world.draw()
	world.drawMap(world.renderMap)
end


function world.keypress(key)

end


function world.mousepress()

end

